@@ -16,4 +16,5 @@
 #---------------------------------------------------------------------------
 import datetime
 
-CCODE = 4689 # Yahoo!
+#CCODE = 4689 # Yahoo!
+CCODE = 8411 # みずほ
